@@ -5,10 +5,10 @@ print.smacofPerm <- function(x,...)
   cat("\n")
   cat("SMACOF Permutation Test\n")
   cat("Number of objects:",x$nobj,"\n")
-  cat("Number of replications:",x$nrep,"\n")
+  cat("Number of replications (permutations):",x$nrep,"\n")
   cat("\n")
-  cat("Nonmetric stress value:",x$stress.nm,"\n")
-  cat("P-value:",x$pval,"\n")
+  cat("Observed stress value:",x$stress.obs,"\n")
+  cat("P-value:", x$pval,"\n")
   cat("\n")
 }
 
